using Blazorise.DataGrid;
using Microsoft.AspNetCore.Components;
using Microsoft.Extensions.Localization;
using System.Security.Claims;
using WF_WebAdmin.Model;
using WF_WebAdmin.Service;

namespace WF_WebAdmin.Pages
{
    public partial class ModifQuiz
    {
        private Quiz[] quiz;

        private int MaxValue = 5;

        private int totalItem;

        private bool showEditQuiz = false;

        private Quiz? selectedQuiz;

        private bool showPopupDelete = false;

        private int page = 1;

        [Inject]
        public ILogger<ModifQuiz> Logger { get; set; }

        [Inject]
        public IStringLocalizer<ModifQuiz> Localizer { get; set; }

        [Inject]
        public IQuizService QuizService { get; set; }

        private async Task OnReadData(DataGridReadDataEventArgs<Quiz> e)
        {
            if (e.CancellationToken.IsCancellationRequested)
            {
                return;
            }

            var response = await QuizService.getSommeQuiz(e.PageSize, e.Page);

            if (!e.CancellationToken.IsCancellationRequested)
            {
                totalItem = await QuizService.getNbQuiz();
                quiz = response.ToArray();
                page = e.Page;
            }
        }

        private void OnEditButtonClicked(Quiz quiz)
        {
            if (quiz == null) return;
            selectedQuiz = quiz;
            showEditQuiz = true;
        }

        private void ClosePopup()
        {
            showEditQuiz = false;
            showPopupDelete = false;
            selectedQuiz = null;
        }

        private async Task EditQuiz()
        {
            LoggerSaveStub.Log(Logger, LogLevel.Information, $"Modification de la question {selectedQuiz.Question}");
            await QuizService.updateQuiz(selectedQuiz);
            selectedQuiz = null;
            ClosePopup();
        }

        private void OnDelete(Quiz q)
        {
            selectedQuiz = q;
            showPopupDelete = true;
        }

        private async void RemoveQuote()
        {
            if (selectedQuiz != null)
            {
                LoggerSaveStub.Log(Logger, LogLevel.Information, $"Supretion de la question {selectedQuiz.Question}");
                await QuizService.removeQuiz(selectedQuiz.Id);
                selectedQuiz = null;
                var response = await QuizService.getSommeQuiz(MaxValue, page);
                quiz = response.ToArray();
            }
            showPopupDelete= false;
        }
    }
}
